@@ -1,4 +1,4 @@
-#include <malloc.h>
+#include "pscol.h"
 
 /**********************************************************************/
 /*                                                                    */
@@ -6,17 +6,10 @@
 /*                                                                    */
 /**********************************************************************/
 
-void convtype(char **col)
+char *convtype(int markup)
 {
  char *nametype[] = {"unk", "user", "state", "mem", "cpu", "size", "tty", 0};
- char *stor;
- int ln;
 
- stor = malloc(40);
- for (ln = 0;col[ln];ln++)
- {
-  sprintf(stor, "%s%s", nametype[col[ln][0] - '1'], col[ln] + 1);
-  col[ln] = malloc(strlen(stor) + 1);
-  strcpy(col[ln], stor);  
- }
+ if (markup < 1 || markup > 6) markup = 1;
+ return strdup(nametype[markup - 1]);
 }
