@@ -1,5 +1,4 @@
-#include <malloc.h>
-#include <stdio.h>
+#include "pscol.h"
 
 /***********************************************************************/
 /*                                                                     */
